@@ -77,6 +77,7 @@ int			myargc;
 char	  **myargv;
 int			assert_enabled = 0;
 char	   *pool_key = NULL;
+
 int
 main(int argc, char **argv)
 {
@@ -222,7 +223,7 @@ main(int argc, char **argv)
 	hba_file = make_absolute_path(hba_file_path, base_dir);
 
 	mypid = getpid();
-	SetProcessGlobalVaraibles(PT_MAIN);
+	SetProcessGlobalVariables(PT_MAIN);
 
 
 	pool_init_config();
@@ -481,7 +482,7 @@ daemonize(void)
 #endif
 
 	mypid = getpid();
-	SetProcessGlobalVaraibles(PT_MAIN);
+	SetProcessGlobalVariables(PT_MAIN);
 	write_pid_file();
 	if (chdir("/"))
 		ereport(WARNING,
